ScaleToFit

Enum ScaleToFit 

#[repr(i32)]
pub enum ScaleToFit { Fill = 0, Start = 1, Center = 2, End = 3, }
源矩形映射到目标矩形时的缩放/对齐策略,对应 SkMatrix::ScaleToFit。 Scale/align policy when mapping a source rect to a destination rect (SkMatrix::ScaleToFit).

用于 Matrix::set_rect_to_rect

Variants



Fill = 0

独立缩放 sx/sy 以完全填满 dst(可能非等比)。 Scale X and Y independently to fill dst (aspect ratio may change).



Start = 1

等比缩放并靠 dst 的「起始」边对齐(与 Skia Start 一致)。 Uniform scale; aligned to the start edge of dst per Skia.



Center = 2

等比缩放并在 dst 内居中。 Uniform scale; centered within dst.



End = 3

等比缩放并靠「结束」边对齐。 Uniform scale; aligned to the end edge of dst.